<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 * @return array An array of default values
 */

function personify_get_default_theme_options() {
	$personify_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',

		// color
		'colorscheme'					=> 'red',
		'colorscheme_hue'				=> '#dd9933',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_label_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'		        => esc_html__( 'Read More', 'personify' ),
		
		// breadcrumb options
		'breadcrumb_enable'         	=> true,
		'breadcrumb_separator'         	=> '-',

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'personify' ), '[the-year]', '[site-link]' ),
		
		'scroll_top_visible'        	=> true,
		'footer_detail_enable'        	=> true,
		'footer_name_enable'        	=> true,
		'footer_firstname'				=> esc_html__( 'Jake', 'personify' ),
		'footer_lastname'				=> esc_html__( 'Gyllenhaal', 'personify' ),

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'show_date' 					=> true,
		'show_author'					=> true,
		'show_category'					=> true,
		'show_comments'					=> true,

		// single post theme options
		'single_post_show_date' 		=> true,
		'single_post_show_author'		=> true,
		'single_post_show_pagination'	=> true,
		'single_post_show_category'		=> true,
		'single_post_show_tags'			=> true,
		'single_post_show_comments'		=> true,

		// Introduction Section
		'introduction_section_enable'	=> false,
		'introduction_title_break'		=> false,

		// About Us Section
		'about_section_enable'			=> false,

		// Featured Posts Section
		'featured_section_enable'		=> false,
		
		// Quotation Section
		'quotation_section_enable'		=> false,

		// Journey Section
		'journey_section_enable'		=> false,

		// Message Section
		'message_section_enable'		=> false,

		// Event Section
		'event_section_enable'			=> false,
		'event_section_title'			=> esc_html__( 'Upcoming Events', 'personify' ),
		'event_social_link'				=> esc_url_raw( 'http://facebook.com' ),
		'event_social_label'			=> esc_html__( 'Like Us for more info about events', 'personify' ),

		// Testimonial Section
		'testimonial_section_enable'	=> false,
		'testimonial_title'				=> esc_html__( 'Their Thoughts', 'personify' ),

	);

	$output = apply_filters( 'personify_default_theme_options', $personify_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}