<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */

$options = personify_get_theme_options();


if ( ! function_exists( 'personify_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Personify 0.1
	 */
	function personify_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'personify_doctype', 'personify_doctype', 10 );


if ( ! function_exists( 'personify_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'personify_before_wp_head', 'personify_head', 10 );

if ( ! function_exists( 'personify_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'personify' ); ?></a>

		<?php
	}
endif;

add_action( 'personify_page_start_action', 'personify_page_start', 10 );

if ( ! function_exists( 'personify_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'personify_page_end_action', 'personify_page_end', 10 );

if ( ! function_exists( 'personify_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_header_start() {
		$options = personify_get_theme_options();
		?>
		<header id="masthead" class="site-header" role="banner">
		<?php
	}
endif;
add_action( 'personify_header_action', 'personify_header_start', 10 );

if ( ! function_exists( 'personify_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_site_branding() {
		$options  = personify_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<?php 
			if ( 'show-all' === $header_txt_logo_extra  || 'logo-only' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) {
				the_custom_logo();
			} ?>
			<div id="site-details">
			<?php if( 'show-all' === $header_txt_logo_extra  || 'title-only' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra ) {
				if ( is_front_page() && is_home() ) : ?>
					<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				<?php else : ?>
					<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
				<?php
				endif;
			} 
			if ( 'show-all' === $header_txt_logo_extra  || 'tagline-only' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) {
				$description = get_bloginfo( 'description', 'display' );
				if ( $description || is_customize_preview() ) : ?>
					<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
				<?php
				endif; 
			}?>
			</div><!-- #site-details -->
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'personify_header_action', 'personify_site_branding', 20 );

if ( ! function_exists( 'personify_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_site_navigation() {
		$options = personify_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
			<button class="menu-toggle <?php echo ( false === $options['menu_label_enable'] ) ? 'menu-label-disabled' : ''; ?>" aria-controls="primary-menu" aria-expanded="false">
				<?php
				echo personify_get_svg( array( 'icon' => 'menu' ) );
				echo personify_get_svg( array( 'icon' => 'close' ) );
				if ( true === $options['menu_label_enable'] ) :
					echo '<span class="menu-label">' . esc_html__( 'Menu', 'personify' ) . '</span>';
				endif;
				?>					
			</button>
			<?php wp_nav_menu( array( 
				'fallback_cb'=>'personify_menu_fallback_cb', 
				'theme_location' 	=> 'primary', 
				'menu_id' 			=> 'primary-menu',
				'menu_class' 		=> 'menu nav-menu',
			) ); ?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'personify_header_action', 'personify_site_navigation', 30 );

if ( ! function_exists( 'personify_header_menu_search' ) ) :
	/**
	 * primary menu search
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_header_menu_search() {
		$output = '<a href="#" class="search">';
		$output .= personify_get_svg( array( 'icon' => 'search' ) );
		$output .= personify_get_svg( array( 'icon' => 'close' ) );
        $output .= '</a>';
        $output .= '<div id="search">';
        $output .= get_search_form( false );
        $output .= '</div>';
        return $output;
	}
endif;

if ( ! function_exists( 'personify_add_nav_search' ) ) :
	/**
	 * primary menu search concatinate 
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_add_nav_search($items, $args) {
	  	if ( $args->theme_location == 'primary' ) {
	        $items = $items;
	        $items .= '<li>'. personify_header_menu_search() .'</li>';
	        return $items;
	  	}
	  	return $items;
	}
endif;
add_filter( 'wp_nav_menu_items', 'personify_add_nav_search', 10, 2 );

if ( ! function_exists( 'personify_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_header_end() {
		?>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'personify_header_action', 'personify_header_end', 50 );

if ( ! function_exists( 'personify_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'personify_content_start_action', 'personify_content_start', 10 );

if ( ! function_exists( 'personify_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'personify_content_end_action', 'personify_content_end', 10 );

if ( ! function_exists( 'personify_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_footer_start() {
		$count = 0;
		$support = get_theme_support( 'footer-widgets' );
		for ( $i = 1; $i <= absint( $support[0] ); $i++ ) {
			if ( is_active_sidebar( 'footer-' . $i ) ) {
				$count++;
			}
		}
		$count = ( $count > 0  ) ? 'footer-widget-active' : '';
		?>
		<footer id="colophon" class="site-footer <?php echo esc_attr( $count ); ?>" role="contentinfo">
		<?php
	}
endif;
add_action( 'personify_footer', 'personify_footer_start', 10 );

if ( ! function_exists( 'personify_footer_detail_section' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_footer_detail_section() { 
		$options = personify_get_theme_options(); 
		if ( false === $options['footer_detail_enable'] ) {
			return;
		}

		if ( true === $options['footer_name_enable'] && ( ( has_nav_menu( 'footer' ) && true === $options['footer_menu_enable'] ) || ( has_nav_menu( 'social' ) && true === $options['footer_social_menu_enable'] ) ) ) {
			$col = 'col-2';
		} else {
			$col = 'col-1';
		}
		?>
		<div class="footer-widgets-area page-section footer-details <?php echo esc_attr( $col ); ?>">
                <div class="wrapper">
                	<?php if ( true === $options['footer_name_enable'] ) :
                		$firstname = ! empty( $options['footer_firstname'] ) ? $options['footer_firstname'] : '';
                		$lastname = ! empty( $options['footer_lastname'] ) ? $options['footer_lastname'] : '';
                	?>
	                    <div class="column-wrapper">
	                        <section id="text" class="widget widget_text">
	                            <div class="textwidget">
	                            	<?php if ( ! empty( $firstname ) ) : ?>
		                                <span class="first-name"><?php echo esc_html( $firstname ); ?></span> 
		                            <?php endif; 

		                            if ( ! empty( $lastname ) ) : ?>
		                                <span class="last-name"><?php echo esc_html( $lastname ); ?></span>
		                            <?php endif; ?>
	                            </div><!-- .textwidget -->
	                        </section><!-- .widget_text -->
	                    </div><!-- .column-wrapper -->
	                <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- .footer-widgets-area -->
	<?php	
	}
endif;
add_action( 'personify_footer', 'personify_footer_detail_section', 20 );

if ( ! function_exists( 'personify_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_footer_site_info() {
		$theme_data = wp_get_theme();
		$options = personify_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
		$copyright_text = $options['copyright_text']; 
		
		$powered_by_text = esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'personify' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>'; 
		?>
		<div class="site-info">
			<div class="wrapper">
				<p>
					<?php echo personify_santize_allow_tag( $copyright_text ); 
					
					if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( '<span> | </span>' );
					}?>
				</p>
				<p class="powered-by">
					<?php echo personify_santize_allow_tag( $powered_by_text ); ?>
				</p>
			</div>
		</div><!-- .site-info -->
		<?php
	}
endif;
add_action( 'personify_footer', 'personify_footer_site_info', 30 );

if ( ! function_exists( 'personify_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_footer_scroll_to_top() {
		$options  = personify_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop">
				<?php echo personify_get_svg( array( 'icon' => 'up-arrow' ) ); ?>
			</div>
		<?php endif;
	}
endif;
add_action( 'personify_footer', 'personify_footer_scroll_to_top', 40 );

if ( ! function_exists( 'personify_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Personify 0.1
	 *
	 */
	function personify_footer_end() {
		?>
		</footer>
		<?php
	}
endif;
add_action( 'personify_footer', 'personify_footer_end', 100 );

if ( ! function_exists( 'personify_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since Personify 0.1
	 */
	function personify_add_breadcrumb() {
		$options = personify_get_theme_options();

		// Bail if Breadcrumb disabled.
		if ( false === $options['breadcrumb_enable'] ) {
			return;
		}
		
		// Bail if Home Page.
		if ( is_front_page() && ! is_home() ) {
			return;
		}

		echo '<div id="breadcrumb-list">
			<div class="wrapper">';
				/**
				 * personify_simple_breadcrumb hook
				 *
				 * @hooked personify_simple_breadcrumb -  10
				 *
				 */
				do_action( 'personify_simple_breadcrumb' );
		echo '</div><!-- .wrapper -->
			</div><!-- #breadcrumb-list -->';
		return;
	}

endif;
add_action( 'personify_simple_breadcrumb_action', 'personify_add_breadcrumb' , 10 );

if ( ! function_exists( 'personify_get_author_profile' ) ) :
	/**
	 * Function to get author profile
	 *
	 * @since Personify 0.1
	 */           
	function personify_get_author_profile(){
		$options = personify_get_theme_options();
		if ( false === $options['single_post_show_author'] ) {
			return;
		} ?>

		<article id="about-author">
		    <div class="admin-image">
		        <?php echo get_avatar( get_the_author_meta( 'ID' ), 150 );  ?>   
		        <div class="separator"></div>         
		    </div>

		    <div class="author-content">
		        <header class="entry-header">
		            <h2 class="entry-title">
		                <?php the_author_posts_link(); ?> 
		            </h2>
		        </header>
		        <span><?php esc_html_e( 'Author', 'personify' ); ?></span>
		    </div><!-- .author-content -->   
		</article><!-- #about-author -->

	<?php
	}	
endif;
add_action( 'personify_author_profile_action', 'personify_get_author_profile' );
